Ptah
====

.. toctree::
   :maxdepth: 2
   
   tutorial.rst
   rdbms.rst
   manageui.rst
   forms.rst
   authentication.rst
   scripts.rst
   populate.rst
   migration.rst
   faq.rst
   api.rst
   license.rst

Subprojects
-----------

* `Ptah Examples <https://github.com/ptahproject/examples>`_ and its 
  `associated documentation <http://ptah-examples.readthedocs.org/>`_.

* `ptah_crowd <https://github.com/ptahproject/ptah_crowd>`_, an out-of-the-box user registration/management sub-system and
  its `associated documentation <http://ptah_crowd.readthedocs.org>`_.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

